"use client";
import React, { useEffect, useState } from "react";
import PaginationComponent from "../Pagination";
import Image from "next/image";
import Link from "next/link";
import { useSearchParams } from "next/navigation";
import {
  FaceBookIcon,
  InstaIcon,
  LocationIcon,
  TwitterIcon,
  WhatsAppIcon,
  WhiteLinkdInIcon,
} from "@/components/Icons";

export const BoatListingCard = ({ initialData }) => {
  const searchParams = useSearchParams();
  const [currentPage, setCurrentPage] = useState(1);
  const [data, setData] = useState(initialData);
  const totalPages = 4;

  const handlePageChange = (pageNumber) => {
    setCurrentPage(pageNumber);
  };
  const modifiedData = [...data.slice(0, 3), { isAd: true }, ...data.slice(3)];
  useEffect(() => {
    const fetchData = async () => {
      const params = new URLSearchParams(searchParams);
      const res = await fetch(
        `${process.env.NEXT_PUBLIC_BASE_URL}/boat/filter?${params.toString()}`
      );
      const result = await res.json();
      setData(result);
    };

    fetchData();
  }, [searchParams]);
  return (
    <div className="flex flex-col w-full xl:me-20 gap-6">
      {modifiedData.map((item, index) => {
        if (item.isAd) {
          return (
            <figure key={`ad-${index}`} className="w-full">
              <Image
                src="/assets/images/ads.png"
                className="w-full min-h-[115px] rounded object-cover"
                height={168}
                width={955}
                alt="ads"
              />
            </figure>
          );
        }
        return (
          <div
            key={item._id}
            className={`flex flex-col sm:flex-row custom-shadow rounded gap-4 md:gap-11 p-5 items-center ${
              index === 3 ? "mt-[180px]" : ""
            }`}
          >
            <figure className="flex items-center lg:min-w-[352px]">
              <Link href={`boat/${item._id}`}>
                <Image
                  className="rounded"
                  src={
                    item?.thumbnailImg?.images[0]?.url
                      ? item?.thumbnailImg?.images[0]?.url
                      : "/assets/images/boat.jpg"
                  }
                  height={253}
                  width={352}
                  alt="boat"
                />
              </Link>
            </figure>
            <div>
              <p className="text-reefGold text-sm">
                <span className="text-darkGray">Power Boat /</span> Motor Boat
              </p>
              <Link href={`boat/${item._id}`}>
                <h2 className="fs-40 capitalize mb-2 font-semibold leading-none">
                  {item.title}
                </h2>
              </Link>
              <p className="text-reefGold mb-3">{item.price} USD</p>
              <div className="flex gap-6 items-center mb-3">
                <p>
                  <span className="font-medium text-lg">Age:</span> {item.age}
                </p>
                <p>
                  <span className="font-medium text-lg">Length:</span>{" "}
                  {item.length} ft
                </p>
              </div>
              <div className="flex gap-3 items-center mb-3">
                <LocationIcon className="text-reefGold" />
                <p>{item.country}</p>
              </div>
              <div>
                <p className="mb-3">Share With:</p>
                <div className="flex gap-3">
                  <Link href="#">
                    <FaceBookIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <InstaIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhiteLinkdInIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <TwitterIcon className="h-[21px] w-[21px]" />
                  </Link>
                  <Link href="#">
                    <WhatsAppIcon className="h-[21px] w-[21px]" />
                  </Link>
                </div>
              </div>
            </div>
          </div>
        );
      })}
      <PaginationComponent
        currentPage={currentPage}
        totalPages={totalPages}
        onPageChange={handlePageChange}
      />
    </div>
  );
};
